@@ -5,13 +5,17 @@ perl.pl - runs Perl language interpreter under Perl virtual environment
 
 =head1 VERSION
 
-version 1.05
+version 1.09
 
 =head1 SYNOPSIS
 
 runs Perl language interpreter under Perl virtual environment
 
-C<[I<environment_path>/bin/]perl.pl [I<argument>]...>
+=over
+
+[I<environment_path>/bin/]B<perl.pl> [I<argument>]...
+
+=back
 
 =cut
 use strict;
@@ -27,6 +31,7 @@ use App::Virtualenv;
 my $virtualenvPath = App::Virtualenv::activate();
 say "Perl virtual environment path: $virtualenvPath" if defined $virtualenvPath;
 exit App::Virtualenv::perl(@ARGV);
+__END__
 =head1 AUTHOR
 
 Orkun Karaduman <orkunkaraduman@gmail.com>
